@@ -1,8 +1,7 @@
 /*
  * QDigiDocClient
  *
- * Copyright (C) 2009 Jargo Kster <jargo@innovaatik.ee>
- * Copyright (C) 2009 Raul Metsma <raul@innovaatik.ee>
+ * Copyright (C) 2009-2010  Estonian Informatics Centre
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,12 +21,13 @@
 
 #include "MainWindow.h"
 
+#include "common/CheckConnection.h"
 #include "common/Common.h"
 #include "common/IKValidator.h"
 #include "common/Settings.h"
-#include "common/PinDialog.h"
 #include "common/SslCertificate.h"
 
+#include "AccessCert.h"
 #include "MobileDialog.h"
 #include "PrintSheet.h"
 #include "SettingsDialog.h"
@@ -36,13 +36,11 @@
 #include <digidocpp/Document.h>
 
 #include <QApplication>
-#include <QDateTime>
 #include <QDesktopServices>
 #include <QDragEnterEvent>
 #include <QFileDialog>
 #include <QMessageBox>
 #include <QPrintPreviewDialog>
-#include <QTcpSocket>
 #include <QTextStream>
 #include <QTranslator>
 #include <QUrl>
@@ -54,13 +52,17 @@
 
 MainWindow::MainWindow( QWidget *parent )
 :	QWidget( parent )
+,	cardsGroup( new QActionGroup( this ) )
 ,	m_loaded( false )
+,	quitOnClose( false )
 {
 	qRegisterMetaType<QSslCertificate>("QSslCertificate");
 
 	setupUi( this );
 
 	cards->hide();
+	cards->hack();
+	languages->hack();
 
 	setWindowFlags( Qt::Window | Qt::CustomizeWindowHint | Qt::WindowMinimizeButtonHint );
 #if QT_VERSION >= 0x040500
@@ -70,16 +72,21 @@ MainWindow::MainWindow( QWidget *parent )
 #endif
 
 	QApplication::instance()->installEventFilter( this );
-	
+
 	Common *common = new Common( this );
 	QDesktopServices::setUrlHandler( "browse", common, "browse" );
 	QDesktopServices::setUrlHandler( "mailto", common, "mailTo" );
 
+	Settings s;
+	// Mobile
 	infoMobileCode->setValidator( new IKValidator( infoMobileCode ) );
+	infoMobileCode->setText( s.value( "Client/MobileCode" ).toString() );
+	infoMobileCell->setText( s.value( "Client/MobileNumber", "+372" ).toString() );
 	connect( infoMobileCode, SIGNAL(textEdited(QString)), SLOT(enableSign()) );
 	connect( infoMobileCell, SIGNAL(textEdited(QString)), SLOT(enableSign()) );
 	connect( infoSignMobile, SIGNAL(toggled(bool)), SLOT(showCardStatus()) );
 
+	// Buttons
 	QButtonGroup *buttonGroup = new QButtonGroup( this );
 
 	buttonGroup->addButton( settings, HeadSettings );
@@ -105,63 +112,73 @@ MainWindow::MainWindow( QWidget *parent )
 
 	connect( infoCard, SIGNAL(linkActivated(QString)), SLOT(parseLink(QString)) );
 
-	appTranslator = new QTranslator( this );
-	commonTranslator = new QTranslator( this );
-	qtTranslator = new QTranslator( this );
-	QApplication::instance()->installTranslator( appTranslator );
-	QApplication::instance()->installTranslator( commonTranslator );
-	QApplication::instance()->installTranslator( qtTranslator );
-
+	// Digidoc
 	doc = new DigiDoc( this );
 	connect( cards, SIGNAL(activated(QString)), doc, SLOT(selectCard(QString)) );
 	connect( doc, SIGNAL(error(QString)), SLOT(showWarning(QString)) );
 	connect( doc, SIGNAL(dataChanged()), SLOT(showCardStatus()) );
 	m_loaded = doc->init();
 
+	// Translations
+	appTranslator = new QTranslator( this );
+	commonTranslator = new QTranslator( this );
+	qtTranslator = new QTranslator( this );
+	QApplication::instance()->installTranslator( appTranslator );
+	QApplication::instance()->installTranslator( commonTranslator );
+	QApplication::instance()->installTranslator( qtTranslator );
+	lang << "et" << "en" << "ru";
+	QString deflang;
+	switch( QLocale().language() )
+	{
+	case QLocale::English: deflang = "en"; break;
+	case QLocale::Russian: deflang = "ru"; break;
+	case QLocale::Estonian:
+	default: deflang = "et"; break;
+	}
+	on_languages_activated( lang.indexOf(
+		s.value( "Main/Language", deflang ).toString() ) );
+	QActionGroup *langGroup = new QActionGroup( this );
+	QAction *etAction = langGroup->addAction( new QAction( langGroup ) );
+	QAction *enAction = langGroup->addAction( new QAction( langGroup ) );
+	QAction *ruAction = langGroup->addAction( new QAction( langGroup ) );
+	etAction->setData( 0 );
+	enAction->setData( 1 );
+	ruAction->setData( 2 );
+	etAction->setShortcut( Qt::CTRL + Qt::SHIFT + Qt::Key_1 );
+	enAction->setShortcut( Qt::CTRL + Qt::SHIFT + Qt::Key_2 );
+	ruAction->setShortcut( Qt::CTRL + Qt::SHIFT + Qt::Key_3 );
+	addAction( etAction );
+	addAction( enAction );
+	addAction( ruAction );
+	connect( langGroup, SIGNAL(triggered(QAction*)), SLOT(changeLang(QAction*)) );
+	connect( cardsGroup, SIGNAL(triggered(QAction*)), SLOT(changeCard(QAction*)) );
+
+	// Views
 	signContentView->setColumnHidden( 2, true );
 	viewContentView->setColumnHidden( 3, true );
 	connect( signContentView, SIGNAL(remove(unsigned int)),
 		SLOT(removeDocument(unsigned int)) );
 	connect( viewContentView, SIGNAL(remove(unsigned int)),
 		SLOT(removeDocument(unsigned int)) );
-	connect( signContentView, SIGNAL(save(unsigned int,QString)),
-		doc, SLOT(saveDocument(unsigned int,QString)) );
-	connect( viewContentView, SIGNAL(save(unsigned int,QString)),
-		doc, SLOT(saveDocument(unsigned int,QString)) );
 
-	Settings s;
-	cards->hack();
-	languages->hack();
-	lang << "et" << "en" << "ru";
-	on_languages_activated( lang.indexOf(
-		s.value( "Main/Language", "et" ).toString() ) );
-
-	s.beginGroup( "Client" );
-	doc->setConfValue( DigiDoc::ProxyHost, s.value( "proxyHost" ) );
-	doc->setConfValue( DigiDoc::ProxyPort, s.value( "proxyPort" ) );
-	doc->setConfValue( DigiDoc::ProxyUser, s.value( "proxyUser" ) );
-	doc->setConfValue( DigiDoc::ProxyPass, s.value( "proxyPass" ) );
-	doc->setConfValue( DigiDoc::PKCS12Cert, s.value( "pkcs12Cert" ) );
-	doc->setConfValue( DigiDoc::PKCS12Pass, s.value( "pkcs12Pass" ) );
-
-	infoMobileCell->setText( s.value( "MobileNumber", "+372" ).toString() );
-	infoMobileCode->setText( s.value( "MobileCode" ).toString() );
-
-	close = new QAction( tr("Close"), this );
-	close->setShortcut( Qt::CTRL + Qt::Key_W );
-	connect( close, SIGNAL(triggered()), this, SLOT(closeDoc()) );
-	addAction( close );
+	// Actions
+	closeAction = new QAction( tr("Close"), this );
+	closeAction->setShortcut( Qt::CTRL + Qt::Key_W );
+	connect( closeAction, SIGNAL(triggered()), this, SLOT(closeDoc()) );
+	addAction( closeAction );
 #if defined(Q_OS_MAC)
 	QMenuBar *bar = new QMenuBar;
 	QMenu *menu = bar->addMenu( tr("&File") );
 	QAction *pref = menu->addAction( tr("Settings"), this, SLOT(showSettings()) );
 	pref->setMenuRole( QAction::PreferencesRole );
-	menu->addAction( close );
+	menu->addAction( closeAction );
 #endif
 
+	// Arguments
 	QStringList args = qApp->arguments();
 	if( args.size() > 1 )
 	{
+		quitOnClose = true;
 		args.removeAt( 0 );
 		params = args;
 		buttonClicked( HomeSign );
@@ -183,7 +200,7 @@ bool MainWindow::addFile( const QString &file )
 		bool select = s.value( "AskSaveAs", false ).toBool();
 		if( !select && QFile::exists( docname ) )
 		{
-			QMessageBox::StandardButton b = QMessageBox::warning( this, windowTitle(),
+			QMessageBox::StandardButton b = QMessageBox::warning( this, tr("DigiDoc3 client"),
 				tr( "%1 already exists.<br />Do you want replace it?" ).arg( docname ),
 				QMessageBox::Yes | QMessageBox::No, QMessageBox::No );
 			select = b == QMessageBox::No;
@@ -192,7 +209,7 @@ bool MainWindow::addFile( const QString &file )
 		if( !Common::canWrite( docname ) )
 		{
 			select = true;
-			QMessageBox::warning( this, windowTitle(),
+			QMessageBox::warning( this, tr("DigiDoc3 client"),
 				tr( "You dont have suficient privilegs to write this fail into folder %1" ).arg( docname ) );
 		}
 
@@ -202,13 +219,13 @@ bool MainWindow::addFile( const QString &file )
 				this, tr("Save file"), docname, tr("Documents (*.bdoc *.ddoc)") );
 			if( docname.isEmpty() )
 				return false;
-			QString ext = QFileInfo( docname ).suffix().toLower();
-			if( ext != "bdoc" || ext != "ddoc" )
+			QStringList exts = QStringList() << "bdoc" << "ddoc";
+			if( !exts.contains( QFileInfo( docname ).suffix(), Qt::CaseInsensitive ) )
 				docname.append( "." + s.value( "type" ,"ddoc" ).toString() );
 			if( !Common::canWrite( docname ) )
 			{
-				QMessageBox::warning( this, windowTitle(),
-					tr( "You dont have permissions to write file %1" ).arg( docname ) );
+				QMessageBox::warning( this, tr("DigiDoc3 client"),
+					tr( "You dont have suficient privilegs to write this fail into folder %1" ).arg( docname ) );
 			}
 			else
 				select = false;
@@ -219,6 +236,14 @@ bool MainWindow::addFile( const QString &file )
 		doc->create( docname );
 	}
 
+	if( !doc->signatures().isEmpty() )
+	{
+		QMessageBox::warning( this, tr("DigiDoc3 client"),
+			tr( "You can not add files to signed document. "
+				"Remove all signatures before adding files.") );
+		return false;
+	}
+
 	// Check if file exist and ask confirmation to overwrite
 	QList<digidoc::Document> docs = doc->documents();
 	for( int i = 0; i < docs.size(); ++i )
@@ -253,7 +278,7 @@ void MainWindow::buttonClicked( int button )
 		showSettings();
 		break;
 	case HeadHelp:
-		QDesktopServices::openUrl( QUrl( "http://support.sk.ee/" ) );
+		QDesktopServices::openUrl( QUrl( "http://code.google.com/p/esteid/wiki/QDigiDocHelp" ) );
 		break;
 	case HomeView:
 	{
@@ -261,11 +286,11 @@ void MainWindow::buttonClicked( int button )
 			QDesktopServices::storageLocation( QDesktopServices::DocumentsLocation ),
 			tr("Documents (*.bdoc *.BDOC *.ddoc *.DDOC)") );
 		if( !file.isEmpty() && doc->open( file ) )
-			setCurrentPage( View );
+			setCurrentPage( doc->signatures().isEmpty() ? Sign : View );
 		break;
 	}
 	case HomeCrypt:
-		if( !Common::startDetached( "qdigidoccrypto", QStringList() << doc->fileName() ) )
+		if( !Common::startDetached( "qdigidoccrypto" ) )
 			showWarning( tr("Failed to start process 'qdigidoccrypto'") );
 		break;
 	case HomeSign:
@@ -280,22 +305,51 @@ void MainWindow::buttonClicked( int button )
 	{
 		if( !params.isEmpty() )
 		{
-			parseParams();
-			break;
-		}
-		QStringList list = QFileDialog::getOpenFileNames( this, tr("Select documents"),
-			QDesktopServices::storageLocation( QDesktopServices::DocumentsLocation ) );
-		if( !list.isEmpty() )
-		{
-			Q_FOREACH( const QString &file, list )
+			Q_FOREACH( const QString &param, params )
 			{
-				if( !addFile( file ) )
+				const QFileInfo f( param );
+				if( !f.isFile() )
+					continue;
+				QStringList exts = QStringList() << "bdoc" << "ddoc";
+				if( doc->isNull() && exts.contains( f.suffix(), Qt::CaseInsensitive ) )
+				{
+					if( doc->open( f.absoluteFilePath() ) )
+						setCurrentPage( doc->signatures().isEmpty() ? Sign : View );
+					params.clear();
 					return;
+				}
+				else if( !addFile( f.absoluteFilePath() ) )
+					break;
 			}
-			setCurrentPage( Sign );
+			params.clear();
+			if( !doc->isNull() )
+				setCurrentPage( Sign );
 		}
-		else if( doc->isNull() )
-			setCurrentPage( Home );
+		else
+		{
+			QStringList list = QFileDialog::getOpenFileNames( this, tr("Select documents"),
+				QDesktopServices::storageLocation( QDesktopServices::DocumentsLocation ) );
+			if( !list.isEmpty() )
+			{
+				Q_FOREACH( const QString &file, list )
+				{
+					if( !addFile( file ) )
+						return;
+				}
+				setCurrentPage( Sign );
+			}
+			else if( doc->isNull() )
+				setCurrentPage( Home );
+		}
+
+		Settings s;
+		s.beginGroup( "Client" );
+		signRoleInput->setText( s.value( "Role" ).toString() );
+		signResolutionInput->setText( s.value( "Resolution" ).toString() );
+		signCityInput->setText( s.value( "City" ).toString() );
+		signStateInput->setText( s.value( "State" ).toString() );
+		signCountryInput->setText( s.value( "Country" ).toString() );
+		signZipInput->setText( s.value( "Zip" ).toString() );
 		break;
 	}
 	case SignCancel:
@@ -307,9 +361,8 @@ void MainWindow::buttonClicked( int button )
 		if( !doc->documents().isEmpty() )
 		{
 			QMessageBox msgBox( QMessageBox::Question, tr("Save container"),
-				tr("You added %1 files to container, but these are not signed yet.\n"
-					"Should I keep unsigned documents or remove these?")
-				.arg( doc->documents().size() ) );
+				tr("You added %n file(s) to container, but these are not signed yet.\n"
+					"Should I keep unsigned documents or remove these?", "", doc->documents().size()) );
 			msgBox.addButton( tr("Remove"), QMessageBox::ActionRole );
 			QPushButton *keep = msgBox.addButton( tr("Keep"), QMessageBox::ActionRole );
 			msgBox.exec();
@@ -327,12 +380,30 @@ void MainWindow::buttonClicked( int button )
 	case IntroBack:
 	case ViewClose:
 		doc->clear();
+		if( quitOnClose )
+			close();
 		setCurrentPage( Home );
 		break;
 	case SignSign:
 	{
-		if( !checkConnection() || !checkAccessCert() )
+		CheckConnection connection;
+		if( !connection.check( "http://ocsp.sk.ee" ) )
+		{
+			showWarning( connection.error() );
 			break;
+		}
+		AccessCert access( this );
+		if( !access.validate() )
+		{
+			if( infoSignMobile->isChecked() || doc->activeCard().isEmpty() )
+			{
+				QDesktopServices::openUrl( QUrl( "http://www.sk.ee/toend/" ) );
+				break;
+			}
+			if( !access.download( doc->signer(), doc->activeCard(),
+					SslCertificate( doc->signCert() ).subjectInfo( "serialNumber" ) ) )
+				break;
+		}
 
 		if( infoSignCard->isChecked() )
 		{
@@ -344,8 +415,6 @@ void MainWindow::buttonClicked( int button )
 		}
 		else
 		{
-			if ( doc->documentType() == digidoc::WDoc::BDocType )
-				QMessageBox::warning( this, windowTitle(), tr( "Mobile-ID BDOC allkirjastamine toimub hetkel SK arenduskeskkonnas!" ), QMessageBox::Ok );
 			MobileDialog *m = new MobileDialog( doc, this );
 			m->setSignatureInfo( signCityInput->text(),
 				signStateInput->text(), signZipInput->text(),
@@ -367,7 +436,6 @@ void MainWindow::buttonClicked( int button )
 			signResolutionInput->text(), signCityInput->text(),
 			signStateInput->text(), signCountryInput->text(),
 			signZipInput->text() );
-		SettingsDialog::saveMobileInfo( infoMobileCode->text(), infoMobileCell->text() );
 		setCurrentPage( View );
 		break;
 	}
@@ -378,15 +446,9 @@ void MainWindow::buttonClicked( int button )
 	}
 }
 
-bool MainWindow::checkConnection()
-{
-	QTcpSocket s;
-	s.connectToHost( "62.65.42.42", 80 );
-	bool status = s.waitForConnected( 5000 );
-	if( !status )
-		showWarning( tr("Check internet connection") );
-	return status;
-}
+void MainWindow::changeCard( QAction *a )
+{ QMetaObject::invokeMethod( doc, "selectCard", Q_ARG(QString,a->data().toString()) ); }
+void MainWindow::changeLang( QAction *a ) { on_languages_activated( a->data().toUInt() ); }
 
 void MainWindow::closeDoc()
 {
@@ -417,10 +479,11 @@ bool MainWindow::eventFilter( QObject *o, QEvent *e )
 	if( e->type() == QEvent::FileOpen )
 	{
 		QFileOpenEvent *o = static_cast<QFileOpenEvent*>(e);
-		if( o->file().right( 4 ).toLower() == "p12d" )
+		QStringList exts = QStringList() << "p12" << "p12d";
+		if( exts.contains( QFileInfo( o->file() ).suffix(), Qt::CaseInsensitive ) )
 		{
 			SettingsDialog s( this );
-			s.addAction( close );
+			s.addAction( closeAction );
 			s.setP12Cert( o->file() );
 			s.exec();
 		}
@@ -437,20 +500,35 @@ bool MainWindow::eventFilter( QObject *o, QEvent *e )
 
 void MainWindow::enableSign()
 {
-	bool mobile = infoSignMobile->isChecked();
+	Settings s;
+	s.beginGroup( "Client" );
+	s.setValue( "MobileCode", infoMobileCode->text() );
+	s.setValue( "MobileNumber", infoMobileCell->text() );
+	s.endGroup();
 
+	if( doc->isNull() || doc->documents().isEmpty() )
+	{
+		signButton->setEnabled( false );
+		return;
+	}
+
+	bool mobile = infoSignMobile->isChecked();
 	if( mobile )
 	{
 		signSigner->setText( QString( "%1 (%2)" )
 			.arg( infoMobileCell->text() ).arg( infoMobileCode->text() ) );
 	}
 
-	if( doc->isNull() ||
-		(mobile && !IKValidator::isValid( infoMobileCode->text() )) ||
+	if( (mobile && !IKValidator::isValid( infoMobileCode->text() )) ||
 		(!mobile && !doc->signCert().isValid()) )
 	{
 		signButton->setEnabled( false );
-		signButton->setToolTip( mobile ? tr("Personal code is not valid") : tr("No card in reader") );
+		if( mobile )
+			signButton->setToolTip( tr("Personal code is not valid") );
+		else if( !doc->signCert().isValid() )
+			signButton->setToolTip( tr("Sign certificate is not valid") );
+		else if( doc->signCert().isNull() )
+			signButton->setToolTip( tr("No card in reader") );
 		return;
 	}
 
@@ -493,7 +571,7 @@ void MainWindow::on_languages_activated( int index )
 	signButton->setText( tr("Sign") );
 	viewAddSignature->setText( tr("Add signature") );
 	showCardStatus();
-	setCurrentPage( (Pages)stack->currentIndex(), false );
+	setCurrentPage( (Pages)stack->currentIndex() );
 }
 
 void MainWindow::parseLink( const QString &link )
@@ -509,7 +587,7 @@ void MainWindow::parseLink( const QString &link )
 				if( !addFile( file ) )
 					return;
 			}
-			setCurrentPage( Sign, false );
+			setCurrentPage( Sign );
 		}
 		else if( doc->isNull() )
 			setCurrentPage( Home );
@@ -525,7 +603,7 @@ void MainWindow::parseLink( const QString &link )
 		QUrl url;
 		url.setScheme( "mailto" );
 		url.addQueryItem( "subject", QFileInfo( doc->fileName() ).fileName() );
-		url.addQueryItem( "attachment", doc->fileName() );
+		url.addQueryItem( "attachment", QFileInfo( doc->fileName() ).absoluteFilePath() );
 		QDesktopServices::openUrl( url );
 	}
 	else if( link == "print" )
@@ -547,23 +625,26 @@ void MainWindow::parseLink( const QString &link )
 		QAbstractItemModel *m = viewContentView->model();
 		for( int i = 0; i < m->rowCount(); ++i )
 		{
-			QString file = QString( "%1/%2" )
+			QString source = m->index( i, 0 ).data( Qt::UserRole ).toString();
+			QString dest = QString( "%1/%2" )
 				.arg( dir ).arg( m->index( i, 0 ).data().toString() );
-			if( QFile::exists( file ) )
+			if( source == dest )
+				continue;
+			if( QFile::exists( dest ) )
 			{
-				QMessageBox::StandardButton b = QMessageBox::warning( this, windowTitle(),
-					tr( "%1 already exists.<br />Do you want replace it?" ).arg( file ),
+				QMessageBox::StandardButton b = QMessageBox::warning( this, tr("DigiDoc3 client"),
+					tr( "%1 already exists.<br />Do you want replace it?" ).arg( dest ),
 					QMessageBox::Yes | QMessageBox::No, QMessageBox::No );
 				if( b == QMessageBox::No )
 				{
-					file = QFileDialog::getSaveFileName( this, tr("Save file"), file );
-					if( file.isEmpty() )
+					dest = QFileDialog::getSaveFileName( this, tr("Save file"), dest );
+					if( dest.isEmpty() )
 						continue;
 				}
 				else
-					QFile::remove( file );
+					QFile::remove( dest );
 			}
-			doc->saveDocument( i, file );
+			QFile::copy( source, dest );
 		}
 	}
 	else if( link == "openUtility" )
@@ -573,68 +654,40 @@ void MainWindow::parseLink( const QString &link )
 	}
 }
 
-void MainWindow::parseParams()
-{
-	Q_FOREACH( const QString &param, params )
-	{
-		const QFileInfo f( param );
-		if( !f.isFile() )
-			continue;
-		const QString suffix = f.suffix().toLower();
-		if( doc->isNull() && (suffix == "bdoc" || suffix == "ddoc") )
-		{
-			if( doc->open( f.absoluteFilePath() ) )
-				setCurrentPage( View );
-			params.clear();
-			return;
-		}
-		else if( !addFile( f.absoluteFilePath() ) )
-			break;
-	}
-	if( !doc->isNull() )
-		setCurrentPage( Sign );
-	params.clear();
-}
-
 void MainWindow::removeDocument( unsigned int index )
 {
 	doc->removeDocument( index );
-	setCurrentPage( (Pages)stack->currentIndex(), false );
+	setCurrentPage( (Pages)stack->currentIndex() );
 }
 
-void MainWindow::setCurrentPage( Pages page, bool reload )
+void MainWindow::setCurrentPage( Pages page )
 {
 	stack->setCurrentIndex( page );
+
+	if( !doc->fileName().isEmpty() )
+	{
+		setWindowTitle( QString( "%1 - %2" )
+			.arg( QFileInfo( doc->fileName() ).fileName() )
+			.arg( tr("DigiDoc3 client") ) );
+	}
+	else
+		setWindowTitle( tr("DigiDoc3 client") );
+
 	switch( page )
 	{
 	case Sign:
 	{
 		signContentView->setContent( doc->documents() );
 		signContentView->setColumnHidden( 3, !doc->signatures().isEmpty() );
-		enableSign();
 		signAddFile->setVisible( doc->signatures().isEmpty() );
-		signButton->setFocus();
-
-		if( !reload )
-			break;
-
-		Settings s;
-		s.beginGroup( "Client" );
-		signRoleInput->setText( s.value( "Role" ).toString() );
-		signResolutionInput->setText( s.value( "Resolution" ).toString() );
-		signCityInput->setText( s.value( "City" ).toString() );
-		signStateInput->setText( s.value( "State" ).toString() );
-		signCountryInput->setText( s.value( "Country" ).toString() );
-		signZipInput->setText( s.value( "Zip" ).toString() );
-		s.endGroup();
+		enableSign();
 		break;
 	}
 	case View:
 	{
 		viewContentView->setContent( doc->documents() );
 
-		Q_FOREACH( SignatureWidget *w, viewSignatures->findChildren<SignatureWidget*>() )
-			w->deleteLater();
+		qDeleteAll( viewSignatures->findChildren<SignatureWidget*>() );
 
 		int i = 0;
 		bool cardOwnerSignature = false, invalid = false, test = false;
@@ -669,7 +722,7 @@ void MainWindow::setCurrentPage( Pages page, bool reload )
 		else
 			viewFileStatus->clear();
 
-		viewSignaturesLabel->setText( signatures.size() == 1 ? tr("Signature") : tr("Signatures") );
+		viewSignaturesLabel->setText( tr( "Signature(s)", "", signatures.size() ) );
 
 		if( invalid )
 			viewSignaturesError->setText( tr("NB! Invalid signature") );
@@ -696,164 +749,52 @@ void MainWindow::showCardStatus()
 	else
 	{
 		infoStack->setCurrentIndex( 0 );
-		QString content;
 		if( !doc->activeCard().isEmpty() && !doc->signCert().isNull() )
 		{
-			content = Common::tokenInfo( Common::SignCert, doc->activeCard(), doc->signCert() );
+			infoCard->setText( Common::tokenInfo( Common::SignCert, doc->activeCard(), doc->signCert() ) );
 			SslCertificate c( doc->signCert() );
 			signSigner->setText( c.toString( c.isTempel() ? "CN (serialNumber)" : "GN SN (serialNumber)" ) );
 		}
 		else if( !doc->activeCard().isEmpty() )
-			content = tr("Loading data");
+			infoCard->setText( tr("Loading data") );
 		else if( doc->activeCard().isEmpty() )
-			content = tr("No card in reader");
-		infoCard->setText( content );
+			infoCard->setText( tr("No card in reader") );
 	}
 
 	cards->clear();
 	cards->addItems( doc->presentCards() );
 	cards->setVisible( doc->presentCards().size() > 1 );
 	cards->setCurrentIndex( cards->findText( doc->activeCard() ) );
+	qDeleteAll( cardsGroup->actions() );
+	for( int i = 0; i < doc->presentCards().size(); ++i )
+	{
+		QAction *a = cardsGroup->addAction( new QAction( cardsGroup ) );
+		a->setData( doc->presentCards().at( i ) );
+		a->setShortcut( Qt::CTRL + (Qt::Key_1 + i) );
+		addAction( a );
+	}
 
 	enableSign();
-	setCurrentPage( (Pages)stack->currentIndex(), false );
+	setCurrentPage( (Pages)stack->currentIndex() );
 }
 
 void MainWindow::showSettings()
 {
 	SettingsDialog e( this );
-	e.addAction( close );
+	e.addAction( closeAction );
 	e.exec();
 }
 
 void MainWindow::showWarning( const QString &msg )
 {
-	QMessageBox d( QMessageBox::Warning, "QDigDocClient", msg, QMessageBox::Close | QMessageBox::Help, this );
+	QMessageBox d( QMessageBox::Warning, tr("DigiDoc3 client"), msg, QMessageBox::Close | QMessageBox::Help, this );
 	if( d.exec() == QMessageBox::Help )
-	{
-		QUrl u( "http://support.sk.ee/" );
-		u.addQueryItem( "searchquery", msg );
-		u.addQueryItem( "searchtype", "all" );
-		u.addQueryItem( "_m", "core" );
-		u.addQueryItem( "_a", "searchclient" );
-		QDesktopServices::openUrl( u );
-	}
+		Common::showHelp( msg );
 }
 
 void MainWindow::viewSignaturesRemove( unsigned int num )
 {
-	SslCertificate c = doc->signatures().at( num ).cert();
-	QString msg = tr("Remove signature %1")
-		.arg( c.toString( c.isTempel() ? "CN serialNumber" : "GN SN serialNumber" ) );
-	QMessageBox::StandardButton b = QMessageBox::warning( this,
-		windowTitle(), msg,
-		QMessageBox::Ok|QMessageBox::Cancel, QMessageBox::Cancel );
-	if( b == QMessageBox::Cancel )
-		return;
 	doc->removeSignature( num );
 	doc->save();
-	setCurrentPage( doc->signatures().isEmpty() ? Sign : View, false );
-}
-
-bool MainWindow::checkAccessCert()
-{
-	Settings s;
-	s.beginGroup( "Client" );
-
-	QString certFile = doc->getConfValue( DigiDoc::PKCS12Cert, s.value( "pkcs12Cert" ) );
-	QString certPass = doc->getConfValue( DigiDoc::PKCS12Pass, s.value( "pkcs12Pass" ) );
-
-	if ( certFile.size() && QFile::exists( certFile ) )
-	{
-		QFile f( certFile );
-		if( f.open( QIODevice::ReadOnly ) )
-		{
-			SslCertificate cert = SslCertificate::fromPKCS12( f.readAll(), certPass.toLatin1() );
-			f.close();
-			if ( !cert.isNull() && cert.isValid() && cert.expiryDate() > QDateTime::currentDateTime().addDays( 8 ) )
-				return true;
-		}
-	}
-
-	if ( QMessageBox::question( this, tr( "Server access certificate" ),
-			tr( "Did not find any server access certificate!\nStart downloading?" ),
-			QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes )  != QMessageBox::Yes )
-		return true;
-
-	if( infoSignMobile->isChecked() || doc->activeCard().isEmpty() )
-	{
-		QDesktopServices::openUrl( QUrl( "http://www.sk.ee/toend/" ) );
-		return false;
-	}
-
-	QString result = doc->getAccessCert();
-	if ( result.isEmpty() )
-	{
-		QMessageBox::warning( this, tr( "Server access certificate" ),
-			tr( "Error downloading server access certificate!" ), QMessageBox::Ok );
-		return false;
-	}
-
-	QDomDocument domDoc;
-	if ( !domDoc.setContent( result ) )
-	{
-		QMessageBox::warning( this, tr( "Server access certificate" ),
-			tr( "Error parsing server access certificate result!" ), QMessageBox::Ok );
-		return false;
-	}
-
-	QDomElement e = domDoc.documentElement();
-	if ( !e.elementsByTagName( "StatusCode" ).size() )
-	{
-		QMessageBox::warning( this, tr( "Server access certificate" ),
-			tr( "Error parsing server access certificate result!" ), QMessageBox::Ok );
-		return false;
-	}
-
-	switch( e.elementsByTagName( "StatusCode" ).item(0).toElement().text().toInt() )
-	{
-	case 1: //need to order cert manually from SK web
-		QDesktopServices::openUrl( QUrl( "http://www.sk.ee/toend/" ) );
-		return false;
-	case 2: //got error, show message from MessageToDisplay element
-		QMessageBox::warning( this, tr( "Server access certificate" ),
-			tr( "Error downloading server access certificate!\n%1" )
-				.arg( e.elementsByTagName( "MessageToDisplay" ).item(0).toElement().text() ),
-			QMessageBox::Ok );
-		return false;
-	default: break; //ok
-	}
-
-	QString cert = e.elementsByTagName( "TokenData" ).item(0).toElement().text();
-	if ( cert.isEmpty() )
-	{
-		QMessageBox::warning( this, tr( "Server access certificate" ),
-			tr( "Error reading server access certificate - empty content!" ), QMessageBox::Ok );
-		return false;
-	}
-
-	QString path = QDesktopServices::storageLocation( QDesktopServices::DataLocation );
-	if ( !QDir( path ).exists() )
-		QDir().mkpath( path );
-
-	QFile file( QString( "%1/%2.p12" )
-		.arg( path )
-		.arg( doc->signCert().subjectInfo( "serialNumber" ) ) );
-	if ( !file.open( QIODevice::WriteOnly|QIODevice::Truncate ) )
-	{
-		QMessageBox::warning( this, tr( "Server access certificate" ),
-			tr("Failed to save server access certificate file to %1!\n%2")
-				.arg( file.fileName() )
-				.arg( file.errorString() ) );
-		return false;
-	}
-	file.write( QByteArray::fromBase64( cert.toLatin1() ) );
-	file.close();
-
-	s.setValue( "pkcs12Cert", file.fileName() );
-	s.setValue( "pkcs12Pass", e.elementsByTagName( "TokenPassword" ).item(0).toElement().text() );
-
-	doc->setConfValue( DigiDoc::PKCS12Cert, s.value( "pkcs12Cert" ) );
-	doc->setConfValue( DigiDoc::PKCS12Pass, s.value( "pkcs12Pass" ) );
-	return true;
+	setCurrentPage( doc->signatures().isEmpty() ? Sign : View );
 }
