@@ -1,8 +1,7 @@
 /*
  * QDigiDocClient
  *
- * Copyright (C) 2009 Jargo Kster <jargo@innovaatik.ee>
- * Copyright (C) 2009 Raul Metsma <raul@innovaatik.ee>
+ * Copyright (C) 2009-2010  Estonian Informatics Centre
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -23,6 +22,7 @@
 #include "RegisterP12.h"
 
 #include <common/Settings.h>
+#include "DigiDoc.h"
 
 #include <QDesktopServices>
 #include <QFile>
@@ -43,9 +43,12 @@ RegisterP12::RegisterP12( const QString &cert, QWidget *parent )
 	qtTranslator->load( ":/translations/qt_" + lang );
 
 	setupUi( this );
+	try { digidoc::initialize(); } catch( const digidoc::Exception & ) {}
 	p12Cert->setText( cert );
 }
 
+RegisterP12::~RegisterP12() { digidoc::terminate(); }
+
 void RegisterP12::on_buttonBox_accepted()
 {
 	QFileInfo file( p12Cert->text() );
@@ -56,6 +59,7 @@ void RegisterP12::on_buttonBox_accepted()
 		return;
 	}
 
+	QDir().mkpath( QDesktopServices::storageLocation( QDesktopServices::DataLocation ) );
 	QString dest = QString( "%1/%2" )
 		.arg( QDesktopServices::storageLocation( QDesktopServices::DataLocation ) )
 		.arg( file.fileName() );
@@ -68,9 +72,8 @@ void RegisterP12::on_buttonBox_accepted()
 		return;
 	}
 
-	Settings s;
-	s.setValue( "Client/pkcs12Cert", dest );
-	s.setValue( "Client/pkcs12Pass", p12Pass->text() );
+	DigiDoc::setConfValue( DigiDoc::PKCS12Cert, dest );
+	DigiDoc::setConfValue( DigiDoc::PKCS12Pass, p12Pass->text() );
 	close();
 }
 
