@@ -1,6 +1,67 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.0" language="et">
+<context>
+    <name>AccessCert</name>
+    <message>
+        <source>Error downloading server access certificate!
+%1</source>
+        <translation>Viga juurdepääsutõendi laadimisel!
+%1</translation>
+    </message>
+    <message>
+        <source>Empty result!</source>
+        <translation>Tühi vastus!</translation>
+    </message>
+    <message>
+        <source>Error parsing server access certificate result!</source>
+        <translation>Viga juurdepääsutõendi lugemisel!</translation>
+    </message>
+    <message>
+        <source>Error reading server access certificate - empty content!</source>
+        <translation>Viga juurdepääsutõendi lugemisel - sisu on tühi!</translation>
+    </message>
+    <message>
+        <source>Failed to save server access certificate file to %1!
+%2</source>
+        <translation>Viga juurdepääsutõendi salvestamisel %1!
+%2</translation>
+    </message>
+    <message>
+        <source>Server access certificate</source>
+        <translation>Juurdepääsutõend</translation>
+    </message>
+    <message>
+        <source>Did not find any server access certificate!
+Start downloading?</source>
+        <translation>Puudub juurdepääsutõend!
+Alustame laadimist?</translation>
+    </message>
+    <message>
+        <source>Failed to read server access certificate!
+Start downloading?</source>
+        <translation>Ei õnnestunud juurdepääsutõendit laadida!
+Alustame laadimist?</translation>
+    </message>
+    <message>
+        <source>Server access certificate password is not valid!
+Start downloading?</source>
+        <translation>Juurdepääsutõendi parool on vale!
+Alustame laadimist?</translation>
+    </message>
+    <message>
+        <source>Server access certificate is not valid!
+Start downloading?</source>
+        <translation>Juurdepääsutõend ei ole kehtiv!
+Alustame laadimist?</translation>
+    </message>
+    <message>
+        <source>Server access certificate is about to expire!
+Start downloading?</source>
+        <translation>Juurdepääsutõend aegub varsti!
+Alustame laadimist?</translation>
+    </message>
+</context>
 <context>
     <name>DigiDoc</name>
     <message>
@@ -9,7 +70,7 @@
     </message>
     <message>
         <source>Cannot add files to signed container</source>
-        <translation>Ei saa lisada faile allakirjutatud ümbrikule</translation>
+        <translation>Ei saa lisada faile allkirjastatud ümbrikule</translation>
     </message>
     <message>
         <source>Missing document</source>
@@ -51,6 +112,10 @@
         <source>An error occurred while opening the document.&lt;br /&gt;%1</source>
         <translation>Ümbriku avamisel tekkis viga.&lt;br /&gt;%1</translation>
     </message>
+    <message>
+        <source>Server access certificate is required</source>
+        <translation>Juurdepääsutõend on vajalik</translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
@@ -96,7 +161,7 @@
     </message>
     <message>
         <source>Sign</source>
-        <translation>Kirjutan alla</translation>
+        <translation>Allkirjastan</translation>
     </message>
     <message>
         <source>Add signature</source>
@@ -124,25 +189,20 @@
     </message>
     <message>
         <source>This container is signed by you</source>
-        <translation>See ümbrik on sinu poolt allakirjutatud</translation>
+        <translation>See ümbrik on sinu poolt allkirjastatud</translation>
     </message>
     <message>
         <source>You have not signed this container</source>
-        <translation>Sa pole seda ümbrikut allkirjastanud</translation>
+        <translation type="unfinished">Sina pole seda ümbrikut allkirjastanud</translation>
     </message>
     <message>
         <source>Container is unsigned</source>
-        <translation>Ümbrik ei ole allakirjutatud</translation>
+        <translation>Ümbrik ei ole allkirjastatud</translation>
     </message>
     <message>
         <source>Select documents</source>
         <translation>Lisa failid</translation>
     </message>
-    <message>
-        <source>You added %1 files to container, but these are not signed yet.
-Should I keep unsigned documents or remove these?</source>
-        <translation>Olete lisanud ümbrikusse %1 faili, kuid pole neid allakirjutanud. Kas jätan allakirjutamata ümbriku alles või kustutan selle?</translation>
-    </message>
     <message>
         <source>Skip this intro</source>
         <translation>Ära rohkem mulle seda sissejuhatust näita</translation>
@@ -153,7 +213,7 @@ Should I keep unsigned documents or remove these?</source>
     </message>
     <message>
         <source>Failed to start process &apos;qdigidoccrypto&apos;</source>
-        <translation>Protsessi &apos;qdigidoccrypto&apos; käivitamine ebaõnnestus</translation>
+        <translation>Protsessi &apos;Digidoc Krüpto&apos; käivitamine ebaõnnestus</translation>
     </message>
     <message>
         <source>Failed to start process &apos;qesteidutil&apos;</source>
@@ -183,10 +243,6 @@ Should I keep unsigned documents or remove these?</source>
         <source>Container content:</source>
         <translation>Ümbriku sisu:</translation>
     </message>
-    <message>
-        <source>Signatures</source>
-        <translation>Allkirjad</translation>
-    </message>
     <message>
         <source>Container:</source>
         <translation>Ümbrik:</translation>
@@ -277,15 +333,14 @@ Digital signing is equal to physical signing. To sign a document you need an ID-
 Signing is done via PIN2 code&lt;br /&gt;&lt;br /&gt;
 Also an active internet connection is needed.&lt;/p&gt;
 &lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
+        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
 &lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;
 &lt;/head&gt;&lt;body&gt;
 &lt;p style=&quot; font: 12px &apos;Arial,Liberation Sans&apos;;&quot;&gt;
 Dokumendi allkirjastamine.&lt;br /&gt;&lt;br /&gt;
 Digitaalallkiri on samaväärne füüsilise allkirjaga. Digitaalallkirja andmiseks on vajalik ID-kaart või Mobiil-ID, millel on kehtiv ja kasutatav allkirjastamise sertifikaat.&lt;br /&gt;&lt;br /&gt;
 Dokumendi allkirjastamisel on vajalik PIN2 kood.&lt;br /&gt;&lt;br /&gt;
-Digitaalallkirja andmiseks on vajalik internetiühendus.
-&lt;/p&gt;
+Digitaalallkirja andmiseks on vajalik internetiühendus.&lt;/p&gt;
 &lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
@@ -296,64 +351,18 @@ Digitaalallkirja andmiseks on vajalik internetiühendus.
         <source>%1 already exists.&lt;br /&gt;Do you want replace it?</source>
         <translation>%1 on juba olemas.&lt;br /&gt;Soovid asendada?</translation>
     </message>
-    <message>
-        <source>Server access certificate</source>
-        <translation>Ligipääsutõend</translation>
-    </message>
-    <message>
-        <source>Did not find any server access certificate!
-Start downloading?</source>
-        <translation>Puudub ligipääsutõend!
-Alustame laadimist?</translation>
-    </message>
-    <message>
-        <source>Error downloading server access certificate!</source>
-        <translation>Viga ligipääsutõendi laadimisel!</translation>
-    </message>
-    <message>
-        <source>Error parsing server access certificate result!</source>
-        <translation>Viga ligipääsutõendi lugemisel!</translation>
-    </message>
-    <message>
-        <source>Error downloading server access certificate!
-%1</source>
-        <translation>Viga ligipääsutõendi laadimisel!
-%1</translation>
-    </message>
-    <message>
-        <source>Check internet connection</source>
-        <translation>Kontrolli interneti ühendust</translation>
-    </message>
     <message>
         <source>Personal code is not valid</source>
         <translation>Isikukood on vigane</translation>
     </message>
-    <message>
-        <source>Failed to save server access certificate file to %1!
-%2</source>
-        <translation>Viga ligipääsutõendi salvestamisel %1!
-%2</translation>
-    </message>
     <message>
         <source>NB! Test signature</source>
         <translation>NB! Test allkiri</translation>
     </message>
-    <message>
-        <source>You dont have permissions to write file %1</source>
-        <translation>Teil ei ole piisavalt õigusi et kirjutada faili %1</translation>
-    </message>
     <message>
         <source>NB! Invalid signature</source>
         <translation>NB: Vigane allkiri</translation>
     </message>
-    <message>
-        <source>Error reading server access certificate - empty content!</source>
-        <translation>Viga ligipääsutõendi lugemisel - sisu on tühi!</translation>
-    </message>
-    <message>
-        <source>Remove signature %1</source>
-        <translation>Eemalda allkiri %1</translation>
-    </message>
     <message>
         <source>You dont have suficient privilegs to write this fail into folder %1</source>
         <translation>Sul ei ole piisavalt õigusi, et kirjutada fail kataloogi %1</translation>
@@ -374,9 +383,30 @@ Alustame laadimist?</translation>
         <source>Close</source>
         <translation>Sulge</translation>
     </message>
+    <message numerus="yes">
+        <source>Signature(s)</source>
+        <translation>
+            <numerusform>Allkiri</numerusform>
+            <numerusform>Allkirjad</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>You added %n file(s) to container, but these are not signed yet.
+Should I keep unsigned documents or remove these?</source>
+        <translation>
+            <numerusform>Oled lisanud ümbrikusse %n faili, kuid pole neid allkirjastanud.
+Kas jätan allkirjastamata ümbriku alles või eemaldan selle?</numerusform>
+            <numerusform>Oled lisanud ümbrikusse %n faili, kuid pole neid allkirjastanud.
+Kas jätan allkirjastamata ümbriku alles või eemaldan selle?</numerusform>
+        </translation>
+    </message>
     <message>
-        <source>Mobile-ID BDOC allkirjastamine toimub hetkel SK arenduskeskkonnas!</source>
-        <translation></translation>
+        <source>You can not add files to signed document. Remove all signatures before adding files.</source>
+        <translation>Allkirjastatud ümbrikule ei saa lisada faile. Eemalda kõigepealt ümbrikult allkirjad.</translation>
+    </message>
+    <message>
+        <source>Sign certificate is not valid</source>
+        <translation>Allkirjastamise sertifikaat ei ole kehtiv</translation>
     </message>
 </context>
 <context>
@@ -445,9 +475,34 @@ Palun kontrollige internetiühendust.</translation>
     </message>
     <message>
         <source>User is not a Mobile-ID client</source>
-        <translatorcomment>Пользователь не является клиентом Mobiil-ID</translatorcomment>
         <translation>Kasutaja ei ole Mobiil-ID klient</translation>
     </message>
+    <message>
+        <source>ID and phone number do not match</source>
+        <translation>Isikukood ja telefoni number ei klapi</translation>
+    </message>
+    <message>
+        <source>Empty HTTP result</source>
+        <translation>Tühi HTTP tulemus</translation>
+    </message>
+    <message>
+        <source>Failed to parse XML document</source>
+        <translation>XML dokumendi parsimine ebaõnnestus</translation>
+    </message>
+    <message>
+        <source>Not allowed to use OCSP service!
+Please check your server access sertificate.</source>
+        <translation>Puudub juurdepääs OCSP teenusele!
+Palun kontrollige juurdepääsutõendi olemasolu.</translation>
+    </message>
+    <message>
+        <source>Sign</source>
+        <translation>Allkirjastan</translation>
+    </message>
+    <message>
+        <source>Certificate status unknown</source>
+        <translation>Sertifikaadi staatus on teadmata</translation>
+    </message>
 </context>
 <context>
     <name>PrintSheet</name>
@@ -560,11 +615,11 @@ Palun kontrollige internetiühendust.</translation>
     </message>
     <message>
         <source>Signing certificate is not selected.</source>
-        <translation type="unfinished"></translation>
+        <translation>Allkirjastamise sertifikaat ei ole valitud.</translation>
     </message>
     <message>
         <source>Failed to login token</source>
-        <translation type="unfinished"></translation>
+        <translation>Vale PIN</translation>
     </message>
     <message>
         <source>PIN Incorrect</source>
@@ -572,16 +627,16 @@ Palun kontrollige internetiühendust.</translation>
     </message>
     <message>
         <source>PIN Locked</source>
-        <translation>PIN on lukus</translation>
-    </message>
-    <message>
-        <source>Failed to login to token &apos;%1&apos;: %2</source>
-        <translation type="unfinished"></translation>
+        <translation>PIN on lukus. PIN koodi saab avada ID-kaardi haldusvahendis.</translation>
     </message>
     <message>
         <source>Failed to sign document</source>
         <translation>Dokumendi allkirjastamine ebaõnnestus</translation>
     </message>
+    <message>
+        <source>Sign certificate is not selected</source>
+        <translation>Allkirjastamise sertifikaat ei ole valitud</translation>
+    </message>
 </context>
 <context>
     <name>RegisterP12</name>
@@ -603,11 +658,11 @@ Palun kontrollige internetiühendust.</translation>
     </message>
     <message>
         <source>OCSP PKCS#12 certificate installer</source>
-        <translation>Ligipääsutõend paigaldamine</translation>
+        <translation>Juurdepääsutõendi paigaldamine</translation>
     </message>
     <message>
         <source>OCSP PKCS#12 certificate</source>
-        <translation>Ligipääsutõend</translation>
+        <translation>Juurdepääsutõend</translation>
     </message>
     <message>
         <source>Password</source>
@@ -616,7 +671,7 @@ Palun kontrollige internetiühendust.</translation>
     <message>
         <source>OCSP PKCS#12 server access certificate is available at&lt;br /&gt;
 &lt;a href=&quot;http://www.sk.ee/getaccess/?lang=eng&quot;&gt;http://www.sk.ee/toend/&lt;/a&gt;</source>
-        <translation>OCSP PKCS#12 serveri ligipääsu sertifikaadid on võimalik saada&lt;br /&gt;
+        <translation>Kehtivuskinnituse serveri juurdepääsutõendi saab SK leheküljelt&lt;br /&gt;
 &lt;a href=&quot;http://www.sk.ee/getaccess/?lang=est&quot;&gt;http://www.sk.ee/toend/&lt;/a&gt;</translation>
     </message>
 </context>
@@ -708,7 +763,7 @@ Palun kontrollige internetiühendust.</translation>
     </message>
     <message>
         <source>OCSP PKCS#12 certificate</source>
-        <translation>Ligipääsutõend</translation>
+        <translation>Juurdepääsutõend</translation>
     </message>
     <message>
         <source>Certificate</source>
@@ -724,7 +779,11 @@ Palun kontrollige internetiühendust.</translation>
     </message>
     <message>
         <source>If you change file format from .bdoc to .ddoc or vise versa, opened file will not change.</source>
-        <translation type="unfinished"></translation>
+        <translation>Juba avatud ümbriku formaati pole võimalik muuta. See seade kehtib ainult uutele ümbrikutele.</translation>
+    </message>
+    <message>
+        <source>Show certificate</source>
+        <translation>Näita sertifikaati</translation>
     </message>
 </context>
 <context>
@@ -806,17 +865,13 @@ Palun kontrollige internetiühendust.</translation>
         <translation>Väärtus</translation>
     </message>
     <message>
-        <source>Verify</source>
+        <source>OCSP</source>
         <translation>Kehtivuskinnitus</translation>
     </message>
     <message>
         <source>Signature is valid</source>
         <translation>Allkiri on kehtiv</translation>
     </message>
-    <message>
-        <source>Signature is not valid (%1)</source>
-        <translation>Allkiri ei ole kehtiv (%1)</translation>
-    </message>
     <message>
         <source>Unknown error</source>
         <translation>Tundmatu viga</translation>
@@ -826,12 +881,20 @@ Palun kontrollige internetiühendust.</translation>
         <translation>Aeg</translation>
     </message>
     <message>
-        <source>Signature status unknown (%1)</source>
-        <translation>Allkirja staatus on teadmata (%1)</translation>
+        <source>Hash value of validity confirmation</source>
+        <translation>Räsi väärtus kehtivuse kinnitamisel</translation>
     </message>
     <message>
-        <source>Hash value of validity confirmation</source>
-        <translation type="unfinished"></translation>
+        <source>Signature is not valid</source>
+        <translation>Allkirja staatus on teadmata</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Abi</translation>
+    </message>
+    <message>
+        <source>Signature status unknown</source>
+        <translation>Signature status unknown</translation>
     </message>
 </context>
 <context>
@@ -872,6 +935,10 @@ Palun kontrollige internetiühendust.</translation>
         <source>unknown</source>
         <translation>teadmata</translation>
     </message>
+    <message>
+        <source>Remove signature %1</source>
+        <translation>Eemalda allkiri %1</translation>
+    </message>
 </context>
 <context>
     <name>TreeWidget</name>
