@@ -1,6 +1,67 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.0" language="ru">
+<context>
+    <name>AccessCert</name>
+    <message>
+        <source>Error downloading server access certificate!
+%1</source>
+        <translation>Ошибка при загрузке справки допуска!
+%1</translation>
+    </message>
+    <message>
+        <source>Empty result!</source>
+        <translation>Пустой ответ!</translation>
+    </message>
+    <message>
+        <source>Error parsing server access certificate result!</source>
+        <translation>Ошибка при чтении справки допуска!</translation>
+    </message>
+    <message>
+        <source>Error reading server access certificate - empty content!</source>
+        <translation>Ошибка при чтении справки допуска! - содержание пустое!</translation>
+    </message>
+    <message>
+        <source>Failed to save server access certificate file to %1!
+%2</source>
+        <translation>Ошибка при сохранении справки допуска! %1!
+%2</translation>
+    </message>
+    <message>
+        <source>Server access certificate</source>
+        <translation>Справка допуска</translation>
+    </message>
+    <message>
+        <source>Did not find any server access certificate!
+Start downloading?</source>
+        <translation>Отсутствует справка допуска!
+Начнём загрузку?</translation>
+    </message>
+    <message>
+        <source>Failed to read server access certificate!
+Start downloading?</source>
+        <translation>Не удалось загрузить справку допуска!
+Начнём загрузку?</translation>
+    </message>
+    <message>
+        <source>Server access certificate password is not valid!
+Start downloading?</source>
+        <translation>Пароль справки допуска неверен!
+Начнём загрузку?</translation>
+    </message>
+    <message>
+        <source>Server access certificate is not valid!
+Start downloading?</source>
+        <translation>Справка допуска не действительна!
+Начнём загрузку?</translation>
+    </message>
+    <message>
+        <source>Server access certificate is about to expire!
+Start downloading?</source>
+        <translation>Срок действия справки допуска скоро истечёт!
+Начнём загрузку?</translation>
+    </message>
+</context>
 <context>
     <name>DigiDoc</name>
     <message>
@@ -51,6 +112,10 @@
         <source>An error occurred while opening the document.&lt;br /&gt;%1</source>
         <translation>При открытии документа произошла ошибка&lt;br /&gt;%1</translation>
     </message>
+    <message>
+        <source>Server access certificate is required</source>
+        <translation>Необходима справка допуска</translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
@@ -84,7 +149,7 @@
     </message>
     <message>
         <source>Failed to start process &apos;qdigidoccrypto&apos;</source>
-        <translation>Запуск процесса &apos;qdigidoccrypto&apos; неудачен</translation>
+        <translation>Запуск процесса &apos;Digidoc Crypto&apos; неудачен</translation>
     </message>
     <message>
         <source>Failed to start process &apos;qesteidutil&apos;</source>
@@ -98,11 +163,6 @@
         <source>Save container</source>
         <translation>Сохранить контейнер</translation>
     </message>
-    <message>
-        <source>You added %1 files to container, but these are not signed yet.
-Should I keep unsigned documents or remove these?</source>
-        <translation>В контейнер добавлено %1 файл(а), но они не подписаны. Оставить неподписанный контейнер или стереть?</translation>
-    </message>
     <message>
         <source>Remove</source>
         <translation>Удалить</translation>
@@ -139,10 +199,6 @@ Should I keep unsigned documents or remove these?</source>
         <source>Signature</source>
         <translation>Подпись</translation>
     </message>
-    <message>
-        <source>Signatures</source>
-        <translation>Подписи</translation>
-    </message>
     <message>
         <source>Loading data</source>
         <translation>Читаю данные</translation>
@@ -208,8 +264,7 @@ Also an active internet connection is needed.&lt;/p&gt;
 Подписывание документов.&lt;br /&gt;&lt;br /&gt;
 Цифровая подпись аналогична физической подписи. Для цифровой подписи нужна ID-карта, которая имеет действующие сертификаты .&lt;br /&gt;&lt;br /&gt;
 При подписывании документов нужен PIN2 код.&lt;br /&gt;&lt;br /&gt;
-Для цифровой подписи необходимо подключение к интернету.
-&lt;/p&gt;
+Для цифровой подписи необходимо подключение к интернету.&lt;/p&gt;
 &lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
@@ -296,64 +351,18 @@ p, li { white-space: pre-wrap; }
         <source>%1 already exists.&lt;br /&gt;Do you want replace it?</source>
         <translation>%1 уже существует.&lt;br /&gt;Заменить?</translation>
     </message>
-    <message>
-        <source>Server access certificate</source>
-        <translation>Справка допуска</translation>
-    </message>
-    <message>
-        <source>Did not find any server access certificate!
-Start downloading?</source>
-        <translation>Отсутствует справка допуска!
-Начнём загрузку?</translation>
-    </message>
-    <message>
-        <source>Error downloading server access certificate!</source>
-        <translation>Ошибка при загрузке справки допуска!</translation>
-    </message>
-    <message>
-        <source>Error parsing server access certificate result!</source>
-        <translation>Ошибка при чтении справки допуска!</translation>
-    </message>
-    <message>
-        <source>Error downloading server access certificate!
-%1</source>
-        <translation>Ошибка при загрузке справки допуска!
-%1</translation>
-    </message>
-    <message>
-        <source>Check internet connection</source>
-        <translation>Проверьте подключение к интернету</translation>
-    </message>
     <message>
         <source>Personal code is not valid</source>
         <translation>Неверный личный код</translation>
     </message>
-    <message>
-        <source>Failed to save server access certificate file to %1!
-%2</source>
-        <translation>Ошибка при сохранении справки допуска! %1!
-%2</translation>
-    </message>
     <message>
         <source>NB! Test signature</source>
         <translation>NB! Пробная подпись</translation>
     </message>
-    <message>
-        <source>You dont have permissions to write file %1</source>
-        <translation>У Вас недостаточно прав для записи файла %1</translation>
-    </message>
     <message>
         <source>NB! Invalid signature</source>
         <translation>NB: Ошибочная подпись</translation>
     </message>
-    <message>
-        <source>Error reading server access certificate - empty content!</source>
-        <translation></translation>
-    </message>
-    <message>
-        <source>Remove signature %1</source>
-        <translation>Удалить подпись %1</translation>
-    </message>
     <message>
         <source>You dont have suficient privilegs to write this fail into folder %1</source>
         <translation>У Вас недостаточно прав для записи файла в каталог %1</translation>
@@ -374,9 +383,33 @@ Start downloading?</source>
         <source>Close</source>
         <translation>Закрыть</translation>
     </message>
+    <message numerus="yes">
+        <source>Signature(s)</source>
+        <translation>
+            <numerusform>Подпись</numerusform>
+            <numerusform>Подписи</numerusform>
+            <numerusform>Подписи</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>You added %n file(s) to container, but these are not signed yet.
+Should I keep unsigned documents or remove these?</source>
+        <translation>
+            <numerusform>В контейнер добавлено %n файл(а), но они не подписаны.
+Оставить неподписанный контейнер или стереть?</numerusform>
+            <numerusform>В контейнер добавлено %n файл(а), но они не подписаны.
+Оставить неподписанный контейнер или стереть?</numerusform>
+            <numerusform>В контейнер добавлено %n файл(а), но они не подписаны.
+Оставить неподписанный контейнер или стереть?</numerusform>
+        </translation>
+    </message>
     <message>
-        <source>Mobile-ID BDOC allkirjastamine toimub hetkel SK arenduskeskkonnas!</source>
-        <translation></translation>
+        <source>You can not add files to signed document. Remove all signatures before adding files.</source>
+        <translation>К подписанному контейнеру нельзя добавить файлы. Удалите прежде с контейнера все подписи.</translation>
+    </message>
+    <message>
+        <source>Sign certificate is not valid</source>
+        <translation>Сертификат подписи недействителен</translation>
     </message>
 </context>
 <context>
@@ -447,12 +480,38 @@ Please check your internet connection.</source>
         <source>User is not a Mobile-ID client</source>
         <translation></translation>
     </message>
+    <message>
+        <source>ID and phone number do not match</source>
+        <translation>Личный код и номер телефона не совпадают</translation>
+    </message>
+    <message>
+        <source>Empty HTTP result</source>
+        <translation>Пустой HTTP ответ</translation>
+    </message>
+    <message>
+        <source>Failed to parse XML document</source>
+        <translation>Ошибка при разборе XML документа</translation>
+    </message>
+    <message>
+        <source>Not allowed to use OCSP service!
+Please check your server access sertificate.</source>
+        <translation>Не разрешено использовать OCSP услугу!
+Пожалуйста проверьте действительность справки допуска.</translation>
+    </message>
+    <message>
+        <source>Sign</source>
+        <translation>Подписать</translation>
+    </message>
+    <message>
+        <source>Certificate status unknown</source>
+        <translation>Статус сертификата неизвестен</translation>
+    </message>
 </context>
 <context>
     <name>PrintSheet</name>
     <message>
         <source>SIGNED FILES</source>
-        <translation>ПОДПИСАННЫЕ ФАИЛЫ</translation>
+        <translation>ПОДПИСАННЫЕ ФАЙЛЫ</translation>
     </message>
     <message>
         <source>FILE NAME</source>
@@ -528,7 +587,7 @@ Please check your internet connection.</source>
     </message>
     <message>
         <source>HASH VALUE OF VALIDITY CONFIRMATION (OCSP RESPONSE)</source>
-        <translation>СОКРАШЕНИЕ СООБЩЕНИЯ ПОДТВЕРЖДЕНИЯ ДЕИСТВИТЕЛЬНОСТИ</translation>
+        <translation>СОКРАЩЕНИЕ СООБЩЕНИЯ ПОДТВЕРЖДЕНИЯ ДЕЙСТВИТЕЛЬНОСТИ</translation>
     </message>
     <message>
         <source>The print out of files listed in the section &lt;b&gt;&quot;Signed Files&quot;&lt;/b&gt; are inseparable part of this Validity Confirmation Sheet.</source>
@@ -559,11 +618,11 @@ Please check your internet connection.</source>
     </message>
     <message>
         <source>Signing certificate is not selected.</source>
-        <translation type="unfinished"></translation>
+        <translation>Сертификат подписи не выбран.</translation>
     </message>
     <message>
         <source>Failed to login token</source>
-        <translation type="unfinished"></translation>
+        <translation>Неверный PIN</translation>
     </message>
     <message>
         <source>PIN Incorrect</source>
@@ -571,15 +630,15 @@ Please check your internet connection.</source>
     </message>
     <message>
         <source>PIN Locked</source>
-        <translation>PIN заблокирован</translation>
-    </message>
-    <message>
-        <source>Failed to login to token &apos;%1&apos;: %2</source>
-        <translation type="unfinished"></translation>
+        <translation>PIN заблокирован. Для разблокирования PIN пожалуйста используйте обслуживание ID-карты!</translation>
     </message>
     <message>
         <source>Failed to sign document</source>
-        <translation type="unfinished"></translation>
+        <translation>Не удалось подписать документ</translation>
+    </message>
+    <message>
+        <source>Sign certificate is not selected</source>
+        <translation>Сертификат подписи не выбран</translation>
     </message>
 </context>
 <context>
@@ -615,7 +674,7 @@ Please check your internet connection.</source>
     <message>
         <source>OCSP PKCS#12 server access certificate is available at&lt;br /&gt;
 &lt;a href=&quot;http://www.sk.ee/getaccess/?lang=eng&quot;&gt;http://www.sk.ee/toend/&lt;/a&gt;</source>
-        <translation>OCSP PKCS#12 сертификат доступа к серверу доступен на&lt;br /&gt;
+        <translation>Подтверждение действительности сервера справки доступа можно получить с веб-страницы SK&lt;br /&gt;
 &lt;a href=&quot;http://www.sk.ee/getaccess/?lang=eng&quot;&gt;http://www.sk.ee/toend/&lt;/a&gt;</translation>
     </message>
 </context>
@@ -723,7 +782,11 @@ Please check your internet connection.</source>
     </message>
     <message>
         <source>If you change file format from .bdoc to .ddoc or vise versa, opened file will not change.</source>
-        <translation type="unfinished"></translation>
+        <translation>Невозможно изменить формат уже открытого конверта. Настройки будут действительны только для новых конвертов.</translation>
+    </message>
+    <message>
+        <source>Show certificate</source>
+        <translation>См. сертификат</translation>
     </message>
 </context>
 <context>
@@ -732,10 +795,6 @@ Please check your internet connection.</source>
         <source>Signature is valid</source>
         <translation>Подпись действительна</translation>
     </message>
-    <message>
-        <source>Signature is not valid (%1)</source>
-        <translation>Подпись недействительна (%1)</translation>
-    </message>
     <message>
         <source>Unknown error</source>
         <translation>Неизвестная ошибка</translation>
@@ -817,7 +876,7 @@ Please check your internet connection.</source>
         <translation>Значение</translation>
     </message>
     <message>
-        <source>Verify</source>
+        <source>OCSP</source>
         <translation>Подтвердить</translation>
     </message>
     <message>
@@ -825,12 +884,20 @@ Please check your internet connection.</source>
         <translation>Время</translation>
     </message>
     <message>
-        <source>Signature status unknown (%1)</source>
-        <translation>Неизвестный статус пользователя (%1)</translation>
+        <source>Hash value of validity confirmation</source>
+        <translation>Хеш-значение при подтверждении действия</translation>
     </message>
     <message>
-        <source>Hash value of validity confirmation</source>
-        <translation type="unfinished"></translation>
+        <source>Signature is not valid</source>
+        <translation>Подпись недействительна</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Помощь</translation>
+    </message>
+    <message>
+        <source>Signature status unknown</source>
+        <translation>Неизвестный статус пользователя</translation>
     </message>
 </context>
 <context>
@@ -845,11 +912,11 @@ Please check your internet connection.</source>
     </message>
     <message>
         <source>valid</source>
-        <translation>действителен</translation>
+        <translation>действительна</translation>
     </message>
     <message>
         <source>not valid</source>
-        <translation>недействителен</translation>
+        <translation>недействительна</translation>
     </message>
     <message>
         <source>Show details</source>
@@ -871,6 +938,10 @@ Please check your internet connection.</source>
         <source>unknown</source>
         <translation>Неизвестно</translation>
     </message>
+    <message>
+        <source>Remove signature %1</source>
+        <translation>Удалить подпись %1</translation>
+    </message>
 </context>
 <context>
     <name>TreeWidget</name>
