@@ -2,7 +2,7 @@
 <!DOCTYPE TS>
 <TS version="2.0" language="et">
 <context>
-    <name>CryptDoc</name>
+    <name>CryptoDoc</name>
     <message>
         <source>Container is not open</source>
         <translation>Turvaümbrik ei ole avatud</translation>
@@ -170,6 +170,18 @@
         <source>Remove</source>
         <translation>Eemalda</translation>
     </message>
+    <message>
+        <source>Are you sure that you want use certificate for encrypting, which expired on %1?&lt;br /&gt;When decrypter has updated certificates then decrypting is impossible.</source>
+        <translation>Kas oled kindel, et soovid kasutada krüpteerimiseks sertifikaati, mis aegus %1?&lt;br /&gt;Juhul, kui dekrüpteerija on oma sertifikaate uuendanud, ei ole dekrüpteerimine võimalik.</translation>
+    </message>
+    <message>
+        <source>Keys added successfully</source>
+        <translation>Adressaat on edukalt lisatud</translation>
+    </message>
+    <message>
+        <source>Failed to add keys</source>
+        <translation>Adressaadi lisamine ebaõnnestus</translation>
+    </message>
 </context>
 <context>
     <name>KeyDialog</name>
@@ -320,8 +332,8 @@ Kas avan Digidoc kliendiga?</translation>
         <translation>Loen andmeid</translation>
     </message>
     <message>
-        <source>&lt;br /&gt;Error code: %1</source>
-        <translation>&lt;br /&gt;Veakood: %1</translation>
+        <source>Error code: %1</source>
+        <translation>Veakood: %1</translation>
     </message>
     <message>
         <source>Yes, I will use ID-card certificate only for secure transfer</source>
@@ -365,7 +377,7 @@ For encryption AS Sertifitseerimiskeskus&apos; LDAP service is used, to search f
 &lt;b&gt;Encryption is one-way only. Private key needed for decryption is stored only on reciever&apos;s ID-card. Decryption of files is impossible if ID-card is lost or damaged, sertificates are expired or renewed. &lt;/b&gt;
 &lt;/p&gt;
 &lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
+        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
 &lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body&gt;
 &lt;p style=&quot; font: 12px &apos;Arial,Liberation Sans&apos;;&quot;&gt;
 &lt;b&gt;Failide krüpteerimine&lt;/b&gt;&lt;br /&gt;&lt;br /&gt;
@@ -389,10 +401,6 @@ Failide krüptimisel kasutatakse AS Sertifitseerimiskeskuse LDAP teenust saaja(t
         <source>Decrypting</source>
         <translation>Dekrüpteerimine</translation>
     </message>
-    <message>
-        <source>Are you sure that you want use certificate for encrypting, which expired on %1?&lt;br /&gt;When decrypter has updated certificates then decrypting is impossible.</source>
-        <translation>Kas oled kindel, et soovid kasutada krüpteerimiseks sertifikaati, mis aegus %1?&lt;br /&gt;Juhul, kui dekrüpteerija on oma sertifikaate uuendanud, ei ole dekrüpteerimine võimalik.</translation>
-    </message>
     <message>
         <source>You dont have permissions to write file %1</source>
         <translation>Sul ei ole piisavalt õigusi et kirjutada faili %1</translation>
@@ -417,6 +425,41 @@ Failide krüptimisel kasutatakse AS Sertifitseerimiskeskuse LDAP teenust saaja(t
         <source>File does not exists %1</source>
         <translation>Valitud faili ei eksisteeri %1</translation>
     </message>
+    <message>
+        <source>Wrong PIN or PIN is blocked</source>
+        <translation>Vale PIN või PIN on lukus</translation>
+    </message>
+</context>
+<context>
+    <name>Poller</name>
+    <message>
+        <source>Authentication certificate is not selected.</source>
+        <translation>Audentimise sertifikaat ei ole valitud.</translation>
+    </message>
+    <message>
+        <source>Failed to login token</source>
+        <translation>Vale PIN</translation>
+    </message>
+    <message>
+        <source>PIN acquisition canceled.</source>
+        <translation>PIN koodi päring katkestati.</translation>
+    </message>
+    <message>
+        <source>PIN Incorrect</source>
+        <translation>Vale PIN</translation>
+    </message>
+    <message>
+        <source>PIN Locked</source>
+        <translation>PIN on lukus</translation>
+    </message>
+    <message>
+        <source>Failed to decrypt document</source>
+        <translation>Dokumenti dekrüpteerimine ebaõnnestus</translation>
+    </message>
+    <message>
+        <source>Failed to load PKCS#11 module</source>
+        <translation>PKCS#11 mooduli laadimine ebaõnnestus</translation>
+    </message>
 </context>
 <context>
     <name>SettingsDialog</name>
@@ -444,6 +487,10 @@ Failide krüptimisel kasutatakse AS Sertifitseerimiskeskuse LDAP teenust saaja(t
         <source>Ask container name</source>
         <translation>Küsi turvaümbriku nime</translation>
     </message>
+    <message>
+        <source>It is not possible to change the file location. Changes will be valid to new containers only.</source>
+        <translation>Juba avatud ümbriku asukohta pole võimalik muuta. See seade kehtib ainult uutele ümbrikutele.</translation>
+    </message>
 </context>
 <context>
     <name>TreeWidget</name>
