@@ -2,7 +2,7 @@
 <!DOCTYPE TS>
 <TS version="2.0" language="ru">
 <context>
-    <name>CryptDoc</name>
+    <name>CryptoDoc</name>
     <message>
         <source>Container is not open</source>
         <translation>Контейнер не открыт</translation>
@@ -170,6 +170,18 @@
         <source>Remove</source>
         <translation>Удалить</translation>
     </message>
+    <message>
+        <source>Are you sure that you want use certificate for encrypting, which expired on %1?&lt;br /&gt;When decrypter has updated certificates then decrypting is impossible.</source>
+        <translation>Вы уверены, что хотите использовать для зашифровки сертификат, который просрочился %1?&lt;br /&gt;В случае, когда расшифровщик обновит сертификат, расшифровка будет невозможна.</translation>
+    </message>
+    <message>
+        <source>Keys added successfully</source>
+        <translation>Адресат успешно добавлен</translation>
+    </message>
+    <message>
+        <source>Failed to add keys</source>
+        <translation>Неудачное добавление ключа</translation>
+    </message>
 </context>
 <context>
     <name>KeyDialog</name>
@@ -237,11 +249,11 @@
     </message>
     <message>
         <source>LDAP server is unavailable.</source>
-        <translation type="unfinished"></translation>
+        <translation>Не могу подключиться к LDAP серверу.</translation>
     </message>
     <message>
         <source>Error Code: %1 (%2)</source>
-        <translation type="unfinished"></translation>
+        <translation>Код ошибки:%1 (%2)</translation>
     </message>
 </context>
 <context>
@@ -300,8 +312,8 @@
         <translation>В считывателе нет карты</translation>
     </message>
     <message>
-        <source>&lt;br /&gt;Error code: %1</source>
-        <translation>&lt;br /&gt;Код ошибки:%1</translation>
+        <source>Error code: %1</source>
+        <translation>Код ошибки:%1</translation>
     </message>
     <message>
         <source>Settings</source>
@@ -365,7 +377,7 @@ For encryption AS Sertifitseerimiskeskus&apos; LDAP service is used, to search f
 &lt;b&gt;Encryption is one-way only. Private key needed for decryption is stored only on reciever&apos;s ID-card. Decryption of files is impossible if ID-card is lost or damaged, sertificates are expired or renewed. &lt;/b&gt;
 &lt;/p&gt;
 &lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
+        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
 &lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body&gt;
 &lt;p style=&quot; font: 12px &apos;Arial,Liberation Sans&apos;;&quot;&gt;
 &lt;b&gt;Шифрование файлов&lt;/b&gt;&lt;br /&gt;&lt;br /&gt;
@@ -389,10 +401,6 @@ For encryption AS Sertifitseerimiskeskus&apos; LDAP service is used, to search f
         <source>Decrypting</source>
         <translation>Расшифровка</translation>
     </message>
-    <message>
-        <source>Are you sure that you want use certificate for encrypting, which expired on %1?&lt;br /&gt;When decrypter has updated certificates then decrypting is impossible.</source>
-        <translation>Вы уверены, что хотите использовать для зашифровки сертификат, который просрочился %1?&lt;br /&gt;В случае, когда расшифровщик обновит сертификат, расшифровка будет невозможна.</translation>
-    </message>
     <message>
         <source>You dont have permissions to write file %1</source>
         <translation>У Вас недостаточно прав, для записи файла %1</translation>
@@ -417,6 +425,41 @@ For encryption AS Sertifitseerimiskeskus&apos; LDAP service is used, to search f
         <source>File does not exists %1</source>
         <translation>Выбраный файл не существует %1</translation>
     </message>
+    <message>
+        <source>Wrong PIN or PIN is blocked</source>
+        <translation>Неправильный PIN или PIN заблокирован</translation>
+    </message>
+</context>
+<context>
+    <name>Poller</name>
+    <message>
+        <source>Authentication certificate is not selected.</source>
+        <translation>Сертификат идентификации не выбран.</translation>
+    </message>
+    <message>
+        <source>Failed to login token</source>
+        <translation>Неверный PIN</translation>
+    </message>
+    <message>
+        <source>PIN acquisition canceled.</source>
+        <translation>Ввод PIN кода был отменен.</translation>
+    </message>
+    <message>
+        <source>PIN Incorrect</source>
+        <translation>Неверный PIN</translation>
+    </message>
+    <message>
+        <source>PIN Locked</source>
+        <translation>PIN заблокирован</translation>
+    </message>
+    <message>
+        <source>Failed to decrypt document</source>
+        <translation>Неудачная зашифровка документа</translation>
+    </message>
+    <message>
+        <source>Failed to load PKCS#11 module</source>
+        <translation>Неудалось загрузить PKCS#11 модуль</translation>
+    </message>
 </context>
 <context>
     <name>SettingsDialog</name>
@@ -444,6 +487,10 @@ For encryption AS Sertifitseerimiskeskus&apos; LDAP service is used, to search f
         <source>Show encrypting intro</source>
         <translation>Показывать подсказку для шифрования</translation>
     </message>
+    <message>
+        <source>It is not possible to change the file location. Changes will be valid to new containers only.</source>
+        <translation>Невозможно изменить расположение уже открытого конверта. Настройки будут действительны только для новых конвертов.</translation>
+    </message>
 </context>
 <context>
     <name>TreeWidget</name>
